@@ -13,6 +13,8 @@
 # limitations under the License.
 
 """Type aliases used by bson"""
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Any, Mapping, MutableMapping, TypeVar, Union
 
 if TYPE_CHECKING:
@@ -26,4 +28,4 @@ if TYPE_CHECKING:
 _DocumentOut = Union[MutableMapping[str, Any], "RawBSONDocument"]
 _DocumentType = TypeVar("_DocumentType", bound=Mapping[str, Any])
 _DocumentTypeArg = TypeVar("_DocumentTypeArg", bound=Mapping[str, Any])
-_ReadableBuffer = Union[bytes, memoryview, "mmap", "array"]
+_ReadableBuffer = Union[bytes, memoryview, bytearray, "mmap", "array"]  # type: ignore[type-arg]
